==> zzyj-financeintegration-api-3.0.0-20220831.064756-55-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMSalaryPayApplyVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class PMSalaryPayApplyVO implements Serializable {



    /**
     * 基础消息信息处理队列（删除数据）
     */
    public static final String SALARY_DEL_RESULT_MESSAGE = "salaryDelResult";


    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 项目ID
     */
    private String projectId;

    /**
     * 合同ID
     */
    private String contractId;

    /**
     * 分包商ID（供应商）
     */
    private String supplierId;

    /**
     * PM单据ID（）
     */
    private String salaryPayApplyId;


    private String quoteFlag;


    private List<PMSalaryPayApplyDetailVO> detailList = new ArrayList<>(); // 工人工资支付申请子实体

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSalaryPayApplyId() {
        return salaryPayApplyId;
    }

    public void setSalaryPayApplyId(String salaryPayApplyId) {
        this.salaryPayApplyId = salaryPayApplyId;
    }

    public String getQuoteFlag() {
        return quoteFlag;
    }

    public void setQuoteFlag(String quoteFlag) {
        this.quoteFlag = quoteFlag;
    }

    public List<PMSalaryPayApplyDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PMSalaryPayApplyDetailVO> detailList) {
        this.detailList = detailList;
    }
}

==> zzyj-financeintegration-api-3.0.0-20251015.082513-127-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMSalaryPayApplyVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class PMSalaryPayApplyVO implements Serializable {



    /**
     * 基础消息信息处理队列（删除数据）
     */
    public static final String SALARY_DEL_RESULT_MESSAGE = "salaryDelResult";


    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 项目ID
     */
    private String projectId;

    /**
     * 合同ID
     */
    private String contractId;

    /**
     * 分包商ID（供应商）
     */
    private String supplierId;

    /**
     * PM单据ID（）
     */
    private String salaryPayApplyId;


    private String quoteFlag;

    /**
     * 总申请金额
     */
    private BigDecimal totalApplyMny;

    private List<PMSalaryPayApplyDetailVO> detailList = new ArrayList<>(); // 工人工资支付申请子实体

    public BigDecimal getTotalApplyMny() {
        return totalApplyMny;
    }

    public void setTotalApplyMny(BigDecimal totalApplyMny) {
        this.totalApplyMny = totalApplyMny;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSalaryPayApplyId() {
        return salaryPayApplyId;
    }

    public void setSalaryPayApplyId(String salaryPayApplyId) {
        this.salaryPayApplyId = salaryPayApplyId;
    }

    public String getQuoteFlag() {
        return quoteFlag;
    }

    public void setQuoteFlag(String quoteFlag) {
        this.quoteFlag = quoteFlag;
    }

    public List<PMSalaryPayApplyDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PMSalaryPayApplyDetailVO> detailList) {
        this.detailList = detailList;
    }
}
